import { EngineObject } from "../@interfaces/EngineObject";
import { Engine } from "./Engine";
export declare abstract class EntitySystem implements EngineObject {
    protected readonly systemClass: typeof EntitySystem;
    private processing;
    priority: number;
    private engine;
    /**
     * Инициализирует EntitySystem с указанным приоритетом.
     * @param priority Приоритет для выполнения этой системы (ниже означает более высокий приоритет).
     */
    constructor(systemClass: typeof EntitySystem, priority?: number);
    getClass(): typeof EntitySystem;
    /**
     * Вызывается при добавлении этой EntitySystem в {@link Engine}.
     * @param engine {@link Engine}, в который была добавлена ​​эта система..
     */
    addedToEngine(engine: Engine): void;
    /**
     * Вызывается, когда эта EntitySystem удаляется из {@link Engine}.
     * @param engine {@link Engine}, из которого была удалена система.
     */
    removedFromEngine(engine: Engine): void;
    /** @return Должна ли система обрабатываться. */
    checkProcessing(): boolean;
    /** Устанавливает, должна ли система обрабатываться {@link Engine}. */
    setProcessing(processing: boolean): void;
    /**
     * @return экземпляр двигателя, в котором зарегистрирована система.
     * Будет нулевым, если система не связана ни с одним экземпляром движка.
     */
    getEngine(): Engine | null;
    /**
     * Метод обновления вызывается каждый тик.
     * @param deltaTime Время, прошедшее с последнего кадра в секундах.
     */
    update(deltaTime: number): void;
    toString(): string;
    hashCode(): number;
    equals(object: EngineObject): boolean;
    addedToEngineInternal(engine: Engine): void;
    removedFromEngineInternal(engine: Engine): void;
}
